Class: Aws::SageMakerRuntime::Types::InvokeEndpointAsyncInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMakerRuntime::Types::InvokeEndpointAsyncInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemakerruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:custom_attributes, :body]
Instance Attribute Summary collapse
-
#accept ⇒ String
The desired MIME type of the inference response from the model container.
-
#body ⇒ String
Provides inline input data for the inference request, in the format specified in the ‘ContentType` request header.
-
#content_type ⇒ String
The MIME type of the input data in the request body.
-
#custom_attributes ⇒ String
Provides additional information about a request for an inference submitted to a model hosted at an Amazon SageMaker AI endpoint.
-
#endpoint_name ⇒ String
The name of the endpoint that you specified when you created the endpoint using the [CreateEndpoint] API.
-
#filename ⇒ String
The filename for the inference response payload stored in Amazon S3.
-
#inference_id ⇒ String
The identifier for the inference request.
-
#input_location ⇒ String
The Amazon S3 URI where the inference request payload is stored.
-
#invocation_timeout_seconds ⇒ Integer
Maximum amount of time in seconds a request can be processed before it is marked as expired.
-
#request_ttl_seconds ⇒ Integer
Maximum age in seconds a request can be in the queue before it is marked as expired.
-
#s3_output_path_extension ⇒ String
The path extension that is appended to the Amazon S3 output path where the inference response payload is stored.
Instance Attribute Details
#accept ⇒ String
The desired MIME type of the inference response from the model container.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#body ⇒ String
Provides inline input data for the inference request, in the format specified in the ‘ContentType` request header. Use this parameter to send the request payload directly in the API call instead of uploading it to Amazon S3 and referencing it with `InputLocation`. The inline payload can be up to 128,000 bytes.
‘Body` and `InputLocation` are mutually exclusive. Provide exactly one of them.
For information about the format of the request body, see [Common Data Formats-Inference].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/cdf-inference.html
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#content_type ⇒ String
The MIME type of the input data in the request body.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#custom_attributes ⇒ String
Provides additional information about a request for an inference submitted to a model hosted at an Amazon SageMaker AI endpoint. The information is an opaque value that is forwarded verbatim. You could use this value, for example, to provide an ID that you can use to track a request or to provide other metadata that a service endpoint was programmed to process. The value must consist of no more than 1024 visible US-ASCII characters as specified in [Section 3.3.6. Field Value Components] of the Hypertext Transfer Protocol (HTTP/1.1).
The code in your model is responsible for setting or updating any custom attributes in the response. If your code does not set this value in the response, an empty value is returned. For example, if a custom attribute represents the trace ID, your model can prepend the custom attribute with ‘Trace ID:` in your post-processing function.
This feature is currently supported in the Amazon Web Services SDKs but not in the Amazon SageMaker AI Python SDK.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#endpoint_name ⇒ String
The name of the endpoint that you specified when you created the endpoint using the [CreateEndpoint] API.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/API_CreateEndpoint.html
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#filename ⇒ String
The filename for the inference response payload stored in Amazon S3. If not specified, Amazon SageMaker AI generates a filename based on the inference ID.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#inference_id ⇒ String
The identifier for the inference request. Amazon SageMaker AI will generate an identifier for you if none is specified.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#input_location ⇒ String
The Amazon S3 URI where the inference request payload is stored.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#invocation_timeout_seconds ⇒ Integer
Maximum amount of time in seconds a request can be processed before it is marked as expired. The default is 15 minutes, or 900 seconds.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#request_ttl_seconds ⇒ Integer
Maximum age in seconds a request can be in the queue before it is marked as expired. The default is 6 hours, or 21,600 seconds.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |
#s3_output_path_extension ⇒ String
The path extension that is appended to the Amazon S3 output path where the inference response payload is stored.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemakerruntime/types.rb', line 148 class InvokeEndpointAsyncInput < Struct.new( :endpoint_name, :content_type, :accept, :custom_attributes, :inference_id, :input_location, :s3_output_path_extension, :filename, :request_ttl_seconds, :invocation_timeout_seconds, :body) SENSITIVE = [:custom_attributes, :body] include Aws::Structure end |